@@ -1,3 +1,5 @@
+# Unit test _estimate_boot_interval ForecasterAutoregCustom
+# ==============================================================================
 from pytest import approx
 import numpy as np
 import pandas as pd
@@ -5,10 +7,10 @@ from skforecast.ForecasterAutoregCustom import ForecasterAutoregCustom
 from sklearn.linear_model import LinearRegression
 
 
-def create_predictors(y):
-    '''
+def create_predictors(y): # pragma: no cover
+    """
     Create first 5 lags of a time series.
-    '''
+    """
     
     lags = y[-1:-6:-1]
     
@@ -16,10 +18,10 @@ def create_predictors(y):
     
 
 def test_estimate_boot_interval_output_when_forecaster_is_LinearRegression_steps_is_1_in_sample_residuals_is_True():
-    '''
+    """
     Test output of _estimate_boot_interval when regressor is LinearRegression and
     1 step is predicted using in-sample residuals.
-    '''
+    """
     forecaster = ForecasterAutoregCustom(
                         regressor      = LinearRegression(),
                         fun_predictors = create_predictors,
@@ -29,4 +31,5 @@ def test_estimate_boot_interval_output_when_forecaster_is_LinearRegression_steps
     forecaster.in_sample_residuals = np.full_like(forecaster.in_sample_residuals, fill_value=10)
     expected = np.array([[20., 20.]])
     results = forecaster._estimate_boot_interval(steps=1, in_sample_residuals=True, n_boot=2)  
-    assert results == approx(expected)
+    
+    assert results == approx(expected)
\ No newline at end of file
