@@ -1,14 +1,15 @@
+# Unit test __init__ ForecasterAutoregCustom
+# ==============================================================================
 import pytest
 import pandas as pd
 from skforecast.ForecasterAutoregCustom import ForecasterAutoregCustom
 from sklearn.linear_model import LinearRegression
 
 
-
-def create_predictors(y):
-    '''
+def create_predictors(y): # pragma: no cover
+    """
     Create first 5 lags of a time series.
-    '''
+    """
     
     lags = y[-1:-6:-1]
     
@@ -16,8 +17,8 @@ def create_predictors(y):
 
 
 def test_init_exception_when_window_size_argument_is_string():
-   '''
-   '''
+   """
+   """
    with pytest.raises(Exception):
         forecaster = ForecasterAutoregCustom(
                         regressor      = LinearRegression(),
@@ -26,8 +27,8 @@ def test_init_exception_when_window_size_argument_is_string():
                     )
 
 def test_init_exception_when_fun_predictors_argument_is_string():
-   '''
-   '''
+   """
+   """
    with pytest.raises(Exception):
         forecaster = ForecasterAutoregCustom(
                         regressor      = LinearRegression(),
