@@ -1,19 +1,23 @@
+# Unit test set_params ForecasterAutoregCustom
+# ==============================================================================
 import pandas as pd
 from skforecast.ForecasterAutoregCustom import ForecasterAutoregCustom
 from sklearn.linear_model import LinearRegression
 
 
-def create_predictors(y):
-    '''
+def create_predictors(y): # pragma: no cover
+    """
     Create first 5 lags of a time series.
-    '''
+    """
     
     lags = y[-1:-6:-1]
     
     return lags  
 
+
 def test_set_paramns():
-    
+    """
+    """
     forecaster = ForecasterAutoregCustom(
                         regressor      = LinearRegression(fit_intercept=True),
                         fun_predictors = create_predictors,
