@@ -1,4 +1,4 @@
-# Unit test __init__
+# Unit test __init__ ForecasterAutoregMultiOutput
 # ==============================================================================
 import pytest
 import numpy as np
@@ -6,6 +6,7 @@ import pandas as pd
 from skforecast.ForecasterAutoregMultiOutput import ForecasterAutoregMultiOutput
 from sklearn.linear_model import LinearRegression
 
+
 def test_init_lags_when_integer():
     '''
     Test creation of attribute lags when integer is passed.
@@ -60,4 +61,4 @@ def test_init_exception_when_lags_list_or_numpy_array_with_values_not_int():
         for lag in lags:
             if not isinstance(lag, (int, np.int64, np.int32)):
                 with pytest.raises(Exception):
-                    ForecasterAutoregMultiOutput(LinearRegression(), lags=lags)
\ No newline at end of file
+                    ForecasterAutoregMultiOutput(LinearRegression(), lags=lags, steps=2)
\ No newline at end of file
