@@ -5,6 +5,7 @@ import numpy as np
 import pandas as pd
 from skforecast.utils import preprocess_last_window
 
+
 def test_output_preprocess_last_window_when_last_window_index_is_DatetimeIndex_and_has_frequency():
     '''
     Test values returned by when last_window is a pandas Series with DatetimeIndex
@@ -60,7 +61,7 @@ def test_output_preprocess_last_window_when_last_window_index_is_not_DatetimeInd
     '''
     Test values returned by when last_window is a pandas Series without DatetimeIndex or RangeIndex.
     '''
-    last_window = pd.Series(data=np.arange(3))
+    last_window = pd.Series(data=np.arange(3), index=['0', '1', '2'])
     results = preprocess_last_window(last_window)
     expected = (np.arange(3),
                 pd.RangeIndex(start=0, stop=3, step=1)
